@@ -7,6 +7,7 @@ use super::*;
 use std::collections::HashMap;
 use std::fs::File;
 use std::io::{BufReader, BufWriter, Write};
+use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::Arc;
 use vrp_cli::core::solver::TargetHeuristic;
 use vrp_cli::extensions::solve::config::create_builder_from_config_file;
@@ -18,7 +19,7 @@ use vrp_core::prelude::*;
 use vrp_core::rosomaxa::evolution::*;
 use vrp_core::rosomaxa::{get_default_population, get_default_selection_size};
 use vrp_core::solver::*;
-use vrp_core::utils::{Parallelism, Quota, TimeQuota};
+use vrp_core::utils::*;
 
 const FORMAT_ARG_NAME: &str = "FORMAT";
 const PROBLEM_ARG_NAME: &str = "PROBLEM";
@@ -36,7 +37,7 @@ const CONFIG_ARG_NAME: &str = "config";
 const LOG_ARG_NAME: &str = "log";
 const CHECK_ARG_NAME: &str = "check";
 const SEARCH_MODE_ARG_NAME: &str = "search-mode";
-const PARALELLISM_ARG_NAME: &str = "parallelism";
+const PARALLELISM_ARG_NAME: &str = "parallelism";
 const HEURISTIC_ARG_NAME: &str = "heuristic";
 const EXPERIMENTAL_ARG_NAME: &str = "experimental";
 const ROUNDED_ARG_NAME: &str = "round";
@@ -282,9 +283,9 @@ pub fn get_solve_app() -> Command<'static> {
                 .default_value("broad"),
         )
         .arg(
-            Arg::new(PARALELLISM_ARG_NAME)
+            Arg::new(PARALLELISM_ARG_NAME)
                 .help("Specifies data parallelism settings in format \"num_thread_pools,threads_per_pool\"")
-                .long(PARALELLISM_ARG_NAME)
+                .long(PARALLELISM_ARG_NAME)
                 .short('p')
                 .required(false)
                 .takes_value(true),
@@ -380,7 +381,7 @@ pub fn run_solve(
                             .unwrap_or_else(|| Ok(Vec::new()))?;
 
                         let solver = if let Some(config) = config {
-                            create_builder_from_config_file(problem.clone(), BufReader::new(config))
+                            create_builder_from_config_file(problem.clone(), solutions, BufReader::new(config))
                                 .and_then(|builder| builder.build())
                                 .map(|config| Solver::new(problem.clone(), config))
                                 .map_err(|err| format!("cannot read config: '{}'", err))?
@@ -459,16 +460,16 @@ fn get_init_size(matches: &ArgMatches) -> Result<Option<usize>, String> {
 }
 
 fn get_environment(matches: &ArgMatches, max_time: Option<usize>) -> Result<Arc<Environment>, String> {
-    let quota = max_time.map::<Arc<dyn Quota + Send + Sync>, _>(|time| Arc::new(TimeQuota::new(time as f64)));
+    let quota = Some(create_interruption_quota(max_time));
 
     matches
-        .value_of(PARALELLISM_ARG_NAME)
+        .value_of(PARALLELISM_ARG_NAME)
         .map(|arg| {
             if let [num_thread_pools, threads_per_pool] =
                 arg.split(',').filter_map(|line| line.parse::<usize>().ok()).collect::<Vec<_>>().as_slice()
             {
                 let parallelism = Parallelism::new(*num_thread_pools, *threads_per_pool);
-                let logger: Arc<fn(&str)> = if matches.is_present(LOG_ARG_NAME) {
+                let logger: InfoLogger = if matches.is_present(LOG_ARG_NAME) {
                     Arc::new(|msg: &str| println!("{}", msg))
                 } else {
                     Arc::new(|_: &str| {})
@@ -527,3 +528,31 @@ fn get_heuristic(
 fn check_pragmatic_solution_with_args(matches: &ArgMatches) -> Result<(), String> {
     check_solution(matches, "pragmatic", PROBLEM_ARG_NAME, OUT_RESULT_ARG_NAME, MATRIX_ARG_NAME)
 }
+
+/// Creates interruption quota.
+pub fn create_interruption_quota(max_time: Option<usize>) -> Arc<dyn Quota + Send + Sync> {
+    struct InterruptionQuota {
+        inner: Option<Arc<dyn Quota + Send + Sync>>,
+        should_interrupt: Arc<AtomicBool>,
+    }
+
+    impl Quota for InterruptionQuota {
+        fn is_reached(&self) -> bool {
+            self.inner.as_ref().map_or(false, |inner| inner.is_reached())
+                || self.should_interrupt.load(Ordering::Relaxed)
+        }
+    }
+
+    let inner = max_time.map::<Arc<dyn Quota + Send + Sync>, _>(|time| Arc::new(TimeQuota::new(time as f64)));
+    let should_interrupt = Arc::new(AtomicBool::new(false));
+
+    // NOTE ignore error which happens in unit tests
+    let _ = ctrlc::set_handler({
+        let should_interrupt = should_interrupt.clone();
+        move || {
+            should_interrupt.store(true, Ordering::Relaxed);
+        }
+    });
+
+    Arc::new(InterruptionQuota { inner, should_interrupt })
+}
