@@ -16,7 +16,7 @@ fn can_import_csv_problem_from_args() {
         "--out-result",
         tmpfile.path().to_str().unwrap(),
     ];
-    let matches = get_import_app().get_matches_from_safe(args).unwrap();
+    let matches = get_import_app().try_get_matches_from(args).unwrap();
 
     let _ = run_import(&matches).unwrap();
 
